
/* 
 * These routines are taken from the standard md5 distribution from
 * coast and contain the implementation of the message digest 
 * algorithm from RFC 1321, modified to have unique names in the case
 * that the program is linking with an external library which contains
 * these standard routines.
 *
 * Modified for use with Mutt by Brandon Long (blong1@ichips.intel.com)
 * on 11/21/96.
 */

/* 
 * MD5.H - header file for MD5C.C
 */

/* Copyright (C) 1991-2, RSA Data Security, Inc. Created 1991. All
 * rights reserved.
 *
 * License to copy and use this software is granted provided that it
 * is identified as the "RSA Data Security, Inc. MD5 Message-Digest
 * Algorithm" in all material mentioning or referencing this software
 * or this function.
 *
 * License is also granted to make and use derivative works provided
 * that such works are identified as "derived from the RSA Data
 * Security, Inc. MD5 Message-Digest Algorithm" in all material
 * mentioning or referencing the derived work.
 *
 * RSA Data Security, Inc. makes no representations concerning either
 * the merchantability of this software or the suitability of this
 * software for any particular purpose. It is provided "as is"
 * without express or implied warranty of any kind.
 *
 * These notices must be retained in any copies of any part of this
 * documentation and/or software.
 */

#ifndef _RFC1321_H
#define _RFC1321_H

/* POINTER defines a generic pointer type */
typedef unsigned char *POINTER;

/* UINT2 defines a two byte word */
typedef unsigned short int UINT2;

/* UINT4 defines a four byte word */
typedef unsigned long int UINT4;

/* MD5 context. */
typedef struct {
  UINT4 state[4];                                   /* state (ABCD) */
  UINT4 count[2];        /* number of bits, modulo 2^64 (lsb first) */
  unsigned char buffer[64];                         /* input buffer */
} rfc1321_MD5_CTX;

void rfc1321_MD5Init(rfc1321_MD5_CTX *);
void rfc1321_MD5Update(rfc1321_MD5_CTX *, unsigned char *, unsigned int);
void rfc1321_MD5Final(unsigned char [16], rfc1321_MD5_CTX *);

#endif /* _RFC1321_H */
